@@ -24,6 +24,7 @@
 
 #include <powerdevilactionconfig.h>
 #include <powerdevilprofilegenerator.h>
+#include <powerdevilpowermanagement.h>
 
 #include <powerdevil_debug.h>
 
@@ -32,12 +33,12 @@
 #include <QLabel>
 #include <QTabBar>
 
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusReply>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusConnectionInterface>
-#include <QtDBus/QDBusMetaType>
-#include <QtDBus/QDBusServiceWatcher>
+#include <QDBusMessage>
+#include <QDBusReply>
+#include <QDBusConnection>
+#include <QDBusConnectionInterface>
+#include <QDBusMetaType>
+#include <QDBusServiceWatcher>
 
 #include <KConfigGroup>
 #include <QDebug>
@@ -51,14 +52,13 @@
 
 #include <Solid/Battery>
 #include <Solid/Device>
-#include <Solid/PowerManagement>
 
 K_PLUGIN_FACTORY(PowerDevilProfilesKCMFactory,
                  registerPlugin<EditPage>();
                 )
 
 EditPage::EditPage(QWidget *parent, const QVariantList &args)
-        : KCModule(0, parent, args)
+        : KCModule(nullptr, parent, args)
 {
     setButtons(Apply | Help | Default);
 
@@ -80,10 +80,9 @@ EditPage::EditPage(QWidget *parent, const QVariantList &args)
 
     if (m_profilesConfig->groupList().isEmpty()) {
         // Use the generator
-        QSet <Solid::PowerManagement::SleepState > methods = Solid::PowerManagement::supportedSleepStates();
         PowerDevil::ProfileGenerator::generateProfiles(
-            methods.contains(Solid::PowerManagement::SuspendState),
-            methods.contains(Solid::PowerManagement::HibernateState)
+            PowerDevil::PowerManagement::instance()->canSuspend(),
+            PowerDevil::PowerManagement::instance()->canHibernate()
         );
         m_profilesConfig->reparseConfiguration();
     }
@@ -196,10 +195,9 @@ void EditPage::restoreDefaultProfiles()
                                                             "Are you sure you want to continue?"), i18n("Restore Default Profiles"));
     if (ret == KMessageBox::Continue) {
         qCDebug(POWERDEVIL) << "Restoring defaults.";
-        QSet <Solid::PowerManagement::SleepState > methods = Solid::PowerManagement::supportedSleepStates();
         PowerDevil::ProfileGenerator::generateProfiles(
-            methods.contains(Solid::PowerManagement::SuspendState),
-            methods.contains(Solid::PowerManagement::HibernateState)
+            PowerDevil::PowerManagement::instance()->canSuspend(),
+            PowerDevil::PowerManagement::instance()->canHibernate()
         );
 
         load();
